@@ -14,8 +14,8 @@
  * SOFTWARE.
  */
 
-extern crate dmntk_examples;
-extern crate dmntk_feel_parser;
+pub extern crate dmntk_examples;
+pub extern crate dmntk_feel_parser;
 extern crate roxmltree;
 
 use crate::model::Definitions;
