@@ -16,9 +16,10 @@
 
 //! Parser for loading a model from the XML file containing DMN interchange format.
 
-use self::{errors::*, xml_utils::*};
+use self::errors::*;
+use self::xml_utils::*;
 use super::*;
-use dmntk_common::Result;
+use dmntk_feel_parser::dmntk_feel::dmntk_common::Result;
 use roxmltree::Node;
 
 const NODE_ALLOWED_ANSWERS: &str = "allowedAnswers";
@@ -66,6 +67,7 @@ const NODE_INVOCATION: &str = "invocation";
 const NODE_ITEM_DEFINITION: &str = "itemDefinition";
 const NODE_ITEM_COMPONENT: &str = "itemComponent";
 const NODE_KNOWLEDGE_REQUIREMENT: &str = "knowledgeRequirement";
+const NODE_KNOWLEDGE_SOURCE: &str = "knowledgeSource";
 const NODE_LITERAL_EXPRESSION: &str = "literalExpression";
 const NODE_OUTPUT: &str = "output";
 const NODE_OUTPUT_ENTRY: &str = "outputEntry";
@@ -225,6 +227,7 @@ impl ModelParser {
     drg_elements.append(&mut self.parse_decisions(node)?);
     drg_elements.append(&mut self.parse_business_knowledge_models(node)?);
     drg_elements.append(&mut self.parse_decision_services(node)?);
+    drg_elements.append(&mut self.parse_knowledge_sources(node)?);
     Ok(drg_elements)
   }
 
@@ -312,6 +315,23 @@ impl ModelParser {
     Ok(drg_elements)
   }
 
+  fn parse_knowledge_sources(&self, node: &Node) -> Result<Vec<DrgElement>> {
+    let mut drg_elements = vec![];
+    for ref child_node in node.children().filter(|n| n.tag_name().name() == NODE_KNOWLEDGE_SOURCE) {
+      let knowledge_source = KnowledgeSource {
+        id: optional_attribute(child_node, ATTR_ID),
+        description: optional_child_optional_content(child_node, NODE_DESCRIPTION),
+        label: optional_attribute(child_node, ATTR_LABEL),
+        extension_elements: None,
+        extension_attributes: vec![],
+        name: required_name(child_node)?,
+        feel_name: optional_feel_name(child_node)?,
+      };
+      drg_elements.push(DrgElement::KnowledgeSource(knowledge_source));
+    }
+    Ok(drg_elements)
+  }
+
   fn required_hrefs_in_child_nodes(&self, node: &Node, child_name: &str) -> Result<Vec<HRef>> {
     let mut hrefs = vec![];
     for ref child_node in node.children().filter(|n| n.tag_name().name() == child_name) {
@@ -980,10 +1000,11 @@ impl ModelParser {
 mod xml_utils {
   use std::str::FromStr;
 
-  use dmntk_common::{OptHRef, Result};
+  use dmntk_feel_parser::dmntk_feel::dmntk_common::{OptHRef, Result};
   use roxmltree::Node;
 
-  use super::{errors::*, *};
+  use super::errors::*;
+  use super::*;
 
   /// Returns the value of the required attribute.
   pub fn required_attribute(node: &Node, attr_name: &str) -> Result<String> {
@@ -1106,7 +1127,7 @@ mod xml_utils {
 
 /// Definitions of errors raised while parsing the XML model.
 mod errors {
-  use dmntk_common::DmntkError;
+  use dmntk_feel_parser::dmntk_feel::dmntk_common::DmntkError;
 
   /// Errors related with parsing the decision model.
   enum ModelParserError {
