@@ -15,6 +15,7 @@
  */
 
 use crate::model::*;
+use dmntk_feel_parser::dmntk_feel::dmntk_common::Stringify;
 
 #[test]
 fn test_2_0001() {
@@ -426,6 +427,18 @@ fn test_3_0085() {
   assert_eq!("_56ed8ec7-c342-4abc-9278-27b46ca991c6", definitions.id().as_ref().unwrap().as_str());
 }
 
+#[test]
+fn test_3_0087() {
+  // <definitions>
+  let definitions = crate::parse(dmntk_examples::DMN_3_0087, "file://3_0087.dmn").unwrap();
+  assert_eq!("_9d01a0c4-f529-4ad8-ad8e-ec5fb5d96ad4", definitions.id().as_ref().unwrap().as_str());
+  // <definitions>.<knowledgeSource>
+  let knowledge_source = definitions.knowledge_source_by_id("_989d137f-86ff-4249-813f-af67c08a2762").unwrap();
+  assert_eq!("_989d137f-86ff-4249-813f-af67c08a2762", knowledge_source.id().as_ref().unwrap().as_str());
+  assert_eq!("Credit officer", knowledge_source.name());
+  assert_eq!(r#"["Credit","officer"]"#, knowledge_source.feel_name().as_ref().unwrap().stringify());
+}
+
 #[test]
 fn test_3_0088() {
   // <definitions>
